pub struct UpdateResult {
pub created: Vec<Exercise>,
pub updated: Vec<Exercise>,
}Expand description
Updated exercises.
Fields
created: Vec<Exercise>updated: Vec<Exercise>Trait Implementations
Sourceimpl Debug for UpdateResult
impl Debug for UpdateResult
Sourceimpl<'de> Deserialize<'de> for UpdateResult
impl<'de> Deserialize<'de> for UpdateResult
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for UpdateResult
impl JsonSchema for UpdateResult
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for UpdateResult
impl RefUnwindSafe for UpdateResult
impl Send for UpdateResult
impl Sync for UpdateResult
impl Unpin for UpdateResult
impl UnwindSafe for UpdateResult